OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "وسم النظام %1$s تمت إضافته بواسطة النظام",
    "Added system tag {systemtag}" : "تمت إضافة وسم النظام {systemtag}",
    "Added system tag %1$s" : "تمت إضافة وسم النظام %1$s",
    "%1$s added system tag %2$s" : "%1$s أضاف وسم النظام%2$s",
    "{actor} added system tag {systemtag}" : "{actor} أضاف وسم النظام {systemtag}",
    "System tag %1$s removed by the system" : " وسم النظام%1$s تمّ حذفه من النظام",
    "Removed system tag {systemtag}" : "تم حذف وسم النظام {systemtag}",
    "Removed system tag %1$s" : "تم حذف وسم النظام %1$s",
    "%1$s removed system tag %2$s" : "%1$s حذف وسم النظام %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} حذف وسم النظام {systemtag}",
    "You created system tag %1$s" : "قمت بإنشاء وسم النظام %1$s",
    "You created system tag {systemtag}" : "قمت بإنشاء وسم النظام {systemtag}",
    "%1$s created system tag %2$s" : "%1$s قام بإنشاء وسم النظام %2$s",
    "{actor} created system tag {systemtag}" : "{actor} قام بإنشاء وسم النظام {systemtag}",
    "You deleted system tag %1$s" : "قمت بحذف وسم النظام %1$s",
    "You deleted system tag {systemtag}" : "قمت بحذف وسم النظام {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s تم حذف وسم النظام %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} تم حذف وسم النظام {systemtag}",
    "You updated system tag %2$s to %1$s" : "أنت غيّرت وسم النظام %2$s إلى %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "قمت بتعديل وسم النظام {oldsystemtag} إلى {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s تم تعديل وسم النظام %3$s إلى %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} تم تعديل وسم النظام {oldsystemtag}  إلى {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "وسم النظام %2$s تمّت إضافته إلى %1$s من قِبل النظام",
    "System tag {systemtag} was added to {file} by the system" : "وسم النظام {systemtag} تمّت إضافته إلى {file} من قِبل النظام",
    "You added system tag %2$s to %1$s" : "أنت قمت بإضافة وسم النظام %2$s إلى %1$s",
    "You added system tag {systemtag} to {file}" : "أنت قمت بإضافة وسم النظام {systemtag}  إلى {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s أضاف وسم النظام %3$s إلى %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} أضاف وسم النظام {systemtag} إلى {file}",
    "System tag %2$s was removed from %1$s by the system" : "وسم النظام %2$s تم حذفه من %1$s من قِبل النظام",
    "System tag {systemtag} was removed from {file} by the system" : "وسم النظام {systemtag} تم حذفه من {file} من قِبل النظام",
    "You removed system tag %2$s from %1$s" : "قمت بحذف وسم النظام %2$s من %1$s",
    "You removed system tag {systemtag} from {file}" : "قمت بحذف وسم النظام {systemtag} من {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s تم حذف وسم النظام %3$s من %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} حذف وسم النظام {systemtag} من {file}",
    "%s (restricted)" : "%s (محظور)",
    "%s (invisible)" : "%s (مخفي)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>وسم النظام</strong> للملف تمّ تغييرها",
    "Files" : "الملفّات",
    "Tags" : "الوسوم",
    "All tagged %s …" : "جميع الوسوم %s …",
    "tagged %s" : "موسوم %s",
    "Collaborative tags" : "الوسوم التعاونية",
    "Collaborative tagging functionality which shares tags among people." : "وظيفة الوسوم التعاونية التي تسمح بمشاركة الوسوم بين المستخدِمين.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "وظيفة الوسوم التعاونية التي تسمح بمشاركة الوسوم بين المستخدِمين.\n\t(إذا كنت مقدم خدمة متعدد الإيجارات multi-tenancy provider، فمن المستحسن إلغاء تنشيط هذا التطبيق حيث تتم مشاركة الوسوم.)",
    "Public" : "عام",
    "Restricted" : "مقيد",
    "Invisible" : "غير مرئي",
    "Created tag" : "تم إنشاء الوسم",
    "Failed to create tag" : "فشل إنشاء الوسم",
    "Updated tag" : "تم تحديث الوسم",
    "Failed to update tag" : "تعذّر تحديث الوسم",
    "Deleted tag" : "تم حذف الوسم",
    "Failed to delete tag" : "فشل حذف الوسم",
    "Create or edit tags" : "إنشاء أو تعديل الوسوم ",
    "Search for a tag to edit" : "البحث عن وسم لتعديله",
    "No tags to select" : "لا توجد أي وسوم للاختيار منها",
    "Tag name" : "اسم الوسم",
    "Tag level" : "مستوى الوسم",
    "Create" : "إنشاء",
    "Update" : "تحديث",
    "Delete" : "حذف ",
    "Reset" : "إعادة تعيين",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} سوف يتم تعيينها؛ بينما {tag2} سوف تتم إزالتها عن {count} ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} ستتم إزالتها عن 1 ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} سوف تتم إزالتها عن {count} ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} سوف تتم إزالتها عن {count} ملفات.","{tag1} سوف يتم تعيينها؛ بينما {tag2} ستتم إزالتها عن {count} ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} ستتم إزالتها عن {count} ملف.."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} سيتم تعيينها لـ {count} ملف.","{tag} سيتم تعيينها لـ 1 ملف.","{tag} سيتم تعيينها لـ {count} ملف.","{tag} سيتم تعيينها لـ {count} ملفات.","{tag} سيتم تعيينها لـ {count} ملف.","{tag} سيتم تعيينها لـ {count} ملف."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} ستتم إزالتها عن {count} ملف.","{tag} ستتم إزالتها عن 1 ملف.","{tag} ستتم إزالتها عن {count} ملف.","{tag} ستتم إزالتها عن {count} ملفات.","{tag} ستتم إزالتها عن {count} ملف.","{tag} ستتم إزالتها عن {count} ملف."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} و {lastTag} سيتم تعيينها لـ {count} ملف.","{tags} و {lastTag} سيتم تعيينها لـ 1 ملف..","{tags} و {lastTag} سيتم تعيينها لـ {count} ملف.","{tags} و {lastTag} سيتم تعيينها لـ {count} ملفات.","{tags} و {lastTag} سيتم تعيينها لـ {count} ملف.","{tags} و {lastTag} سيتم تعيينها لـ {count} ملف."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} و {lastTag} ستتم إزالتها عن {count} ملف.","{tags} و{lastTag} ستتم إزالتها عن 1 ملف.","{tags} و {lastTag} ستتم إزالتها عن {count} ملف..","{tags} و {lastTag} ستتم إزالتها عن {count} ملفات.","{tags} و {lastTag} ستتم إزالتها عن {count} ملف.","{tags} و {lastTag} ستتم إزالتها عن {count} ملف."],
    "{displayName} (hidden)" : "{displayName} (مخفي)",
    "{displayName} (restricted)" : "{displayName} (محضور)",
    "Only admins can create new tags" : "المشرفون وحدهم يمكنهم إنشاء وسوم جديدة",
    "Failed to apply tags changes" : "تعذّر تطبيق التغييرات في الوسوم",
    "Manage tags" : "إدارة الوسوم",
    "Applying tags changes…" : "يتم تطبيق التغييرات في الوسوم...",
    "Search or create tag" : "إنشاء أو بحث عن وسم",
    "Search tag" : "البحث عن وسم",
    "Change tag color" : "تغيير لون الوسم",
    "Create new tag" : "إنشاء وسم جديد",
    "Cancel" : "إلغاء",
    "Apply" : "حفظ",
    "Failed to load selected tags" : "فشل في تحميل الوسوم المنتقاة",
    "Failed to load tags" : "فشل في تحميل الوسوم",
    "Failed to select tag" : "فشل في اختيار وسم",
    "System admin disabled tag creation. You can only use existing ones." : "مشرف النظام قام بمنع إنشاء وُسُوم جديدة. يمكنك فقط الاختيار من بين الوُسُوم الموجودة.",
    "Search or create collaborative tags" : "إنشاء أو البحث عن وسم تعاوني",
    "No tags to select, type to create a new tag" : "لا توجد أي وسوم؛ أكتب لإنشاء وسم جديد",
    "Unable to update setting" : "تعذّر تحديث الإعدادات",
    "System tag creation is now restricted to administrators" : "إنشاء الوُسُوم النظامية يقتَصِر الآن على المشرفين",
    "System tag creation is now allowed for everybody" : "إنشاء الوُسُوم النظامية مُسموحٌ الآن للجميع",
    "System tag management" : "إدارة الوسوم النظامية",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "عند تمكنيها، يمكن للمشرفين فقط إنشاء وتعديل الوسوم. باقي الحسابات مايزال بإمكانها إسنادها إلى وإزالتها عن الملفات. ",
    "Restrict tag creation and editing to administrators" : "تقييد إنشاء وتعديل الوسوم على المشرفين",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "الوسوم التعاونية متاحة لكل المستخدمين. الوسوم المقيدة restricted يمكن للمستخدمين رؤيتها لكن لا يمكنهم إسنادها. الوسوم المخفية invisible للاستعمال الداخلي فقط حيث لا يستطيع المستخدمون رؤيتها و لا إسنادها.",
    "Add tags" : "إضافة سِمَاتٍ",
    "Assigned collaborative tags" : "الوسوم التعاونية المُسندَة",
    "Open in Files" : "إفتَح في \"الملفات\"",
    "List of tags and their associated files and folders." : "قائمة بالوسوم والملفات والمجلدات الموسومة بها.",
    "No tags found" : "لم يعثر على أي وسم",
    "Tags you have created will show up here." : "الوسوم التي قمت بإنشائها ستظهر هنا.",
    "Failed to load tag" : "تعذّر رفع السمة",
    "Failed to load last used tags" : "فشل في تحميل آخر الوسوم استعمالاً",
    "Missing \"Content-Location\" header" : "ترويسة موقع المحتوى  \"Content-Location\" مفقودة",
    "A tag with the same name already exists" : "توجد سمة بنفس الاسم مسبقاً",
    "Failed to load tags for file" : "تعذّر تحميل وسوم الملف",
    "Failed to set tag for file" : "تعذّر وضع وسم على الملف",
    "Failed to delete tag for file" : "تعذّر حذف وسم من على ملف",
    "Collaborative tags …" : "وسوم تعاونية...",
    "Loading …" : "التحميل جارٍ …",
    "File tags modification canceled" : "تمّ إلغاء تعديل وسوم الملف",
    "Select or create tags to apply to all selected files" : "إختيار أو إنشاء وسوم لتطبيقها على جميع الملفات المحددة",
    "Select tags to apply to all selected files" : "إختَر وسوماً لإضافتها لجميع الملفات المُحدَّدة",
    "Apply changes" : "تطبيق التغييرات",
    "Loading collaborative tags …" : "تحميل الوسوم التعاونية ..."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
